@@ -1,4 +1,4 @@
-# externa; imports
+# external imports
 from itertools import compress
 import numpy as np
 from tqdm import tqdm
@@ -49,16 +49,6 @@ class Chain:
             Starting point for the MCMC sampler, default is None (random draw from prior).
         '''
         
-        # if the proposal is pCN, Check if the proposal covariance is equal 
-        # to the prior covariance and if the prior is zero mean.
-        if isinstance(proposal, CrankNicolson) and not isinstance(link_factory.prior, stats._multivariate.multivariate_normal_frozen):
-            raise TypeError('Prior must be of type scipy.stats.multivariate_normal for pCN proposal')
-        
-        # check the same if the CrankNicolson is nested in a MultipleTry proposal.
-        elif hasattr(proposal, 'kernel'):
-            if isinstance(proposal.kernel, CrankNicolson) and not isinstance(link_factory.prior, stats._multivariate.multivariate_normal_frozen):
-                raise TypeError('Prior must be of type scipy.stats.multivariate_normal for pCN kernel')
-        
         # internalise the link factory and the proposal
         self.link_factory = link_factory
         self.proposal = proposal
@@ -85,6 +75,7 @@ class Chain:
         self.proposal.setup_proposal(parameters=self.initial_parameters, link_factory=self.link_factory)
         
     def sample(self, iterations, progressbar=True):
+        
         '''
         Parameters
         ----------
@@ -136,9 +127,9 @@ class Chain:
 class DAChain:
     
     '''
-    DAChain is a two-level Delayed Acceptance sampler with finite length
-    subchains. It takes a coarse and a fine link factory as input, as well
-    as a proposal, which applies to the coarse level only.
+    DAChain is a two-level Delayed Acceptance sampler. It takes a coarse 
+    and a fine link factory as input, as well as a proposal, which applies 
+    to the coarse level only.
     
     Attributes
     ----------
@@ -179,6 +170,7 @@ class DAChain:
     '''
     
     def __init__(self, link_factory_coarse, link_factory_fine, proposal, subsampling_rate=1, initial_parameters=None, adaptive_error_model=None, R=None):
+        
         '''
         Parameters
         ----------
@@ -198,20 +190,10 @@ class DAChain:
             The adaptive error model, see e.g. Cui et al. (2019). Default is None (no error model),
             options are 'state-independent' or 'state-dependent'. If an error model is used, the
             likelihood MUST have a set_bias() method, use e.g. tinyDA.AdaptiveLogLike.
-        R : numpy.ndarray, optional
+        R : numpy.ndarray or None, optional
             Restriction matrix for the adaptive error model. Default is None (identity matrix).
         '''
         
-        # if the proposal is pCN, Check if the proposal covariance is equal 
-        # to the prior covariance and if the prior is zero mean.
-        if isinstance(proposal, CrankNicolson) and not isinstance(link_factory_coarse.prior, stats._multivariate.multivariate_normal_frozen):
-            raise TypeError('Prior must be of type scipy.stats.multivariate_normal for pCN proposal')
-        
-        # check the same if the CrankNicolson is nested in a MultipleTry proposal.
-        elif hasattr(proposal, 'kernel'):
-            if isinstance(proposal.kernel, CrankNicolson) and not isinstance(link_factory_coarse.prior, stats._multivariate.multivariate_normal_frozen):
-                raise TypeError('Prior must be of type scipy.stats.multivariate_normal for pCN kernel')
-        
         # internalise link factories and the proposal
         self.link_factory_coarse = link_factory_coarse
         self.link_factory_fine = link_factory_fine
